$VerbosePreference = "Continue"
$DebugPreference = "Continue"
$certSubject = "*E=easion@gmail.com, O=screenspot.tv, L=GZ, S=GD, C=CN*"

#Write-Host "Current execution policy:"
Get-ExecutionPolicy -List | Format-Table -AutoSize

$isAdmin = ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator)

$scriptDir = Split-Path -Parent $MyInvocation.MyCommand.Path
$certPath = Join-Path $scriptDir "screenspot.crt"

Write-Host "Script Dir: $scriptDir"
Write-Host "Certificate Path: $certPath"

$certExists = Test-Path $certPath

$isAdmin = ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator)
Write-Host "Do you have administrator privileges: $isAdmin"

$certExists = Test-Path $certPath

if (-not $certExists) {
    Write-Host "Error: Certificate file does not exist! Please make sure the $certPath file exists."
    Read-Host -Prompt "Press Enter to exit"
    Exit
}

try {
    Write-Host "Trying to import the certificate..."
    $result = Import-Certificate -FilePath $certPath -CertStoreLocation Cert:\LocalMachine\Root -Verbose
    Write-Host "Result:"
    $result | Format-List
}
catch {
    Write-Host "错误详情："
    Write-Host "错误类型: $($_.Exception.GetType().FullName)"
    Write-Host "错误消息: $($_.Exception.Message)"
    Write-Host "错误位置: $($_.InvocationInfo.PositionMessage)"
    Write-Host "堆栈跟踪: $($_.ScriptStackTrace)"
}

Write-Host "Check if the certificate is installed..."
$installedCert = Get-ChildItem Cert:\LocalMachine\Root | Where-Object { $_.Subject -like $certSubject }
if ($installedCert) {
    Write-Host "Find the installed certificates:"
    $installedCert | Format-List
    Read-Host -Prompt "Installation successful, please press Enter to exit"
} else {
    Write-Host "No installed certificate found"
    Read-Host -Prompt "Installation Failed, Press Enter to exit"
}

