# Enable verbose debug output
$VerbosePreference = "Continue"

# Check administrator privileges
$isAdmin = ([Security.Principal.WindowsPrincipal] [Security.Principal.WindowsIdentity]::GetCurrent()).IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator)
Write-Host "Running with administrator privileges: $isAdmin"

if (-not $isAdmin) {
    Write-Host "Administrator privileges required to uninstall certificate!"
    Exit
}

# Replace with your certificate subject name
$certSubject = "E=easion@gmail.com, O=screenspot.tv, L=GZ, S=GD, C=CN"
#$certSubject = "CN=screenspot.tv"

try {
    Write-Host "Searching for certificate..."
    # Find certificate with specified subject name
    $cert = Get-ChildItem Cert:\LocalMachine\Root | Where-Object { $_.Subject -eq $certSubject }
    
    if ($cert) {
        Write-Host "Certificate found, removing..."
        $cert | Remove-Item -Verbose
        Write-Host "Certificate successfully removed"
    } else {
        Write-Host "No matching certificate found"
    }
}
catch {
    Write-Host "Error details:"
    Write-Host "Error message: $($_.Exception.Message)"
}

# Verify certificate removal
$certExists = Get-ChildItem Cert:\LocalMachine\Root | Where-Object { $_.Subject -eq $certSubject }
if (-not $certExists) {
    Write-Host "Confirmation: Certificate has been successfully removed"
} else {
    Write-Host "Warning: Certificate may not have been completely removed"
}

Read-Host -Prompt "Press Enter to exit"
